==> 0.0.66.tar.gz: lib/JsonFormComponent/components/simple_checkbox.dart <==
import 'package:bui_component/Constants/AppColors.dart';
import 'package:bui_component/Constants/fontFamily.dart';
import 'package:bui_component/Constants/fontSize.dart';
import 'package:flutter/material.dart';

import '../functions.dart';

class SimpleListCheckbox extends StatefulWidget {
  SimpleListCheckbox({
    Key key,
    this.item,
    this.onChange,
    this.position,
    this.errorMessages = const {},
    this.validations = const {},
    this.decorations = const {},
    this.keyboardTypes = const {},
    this.primaryColor,
    this.secondaryColor,
  }) : super(key: key);
  final Color primaryColor;
  final Color secondaryColor;
  final dynamic item;
  final Function onChange;
  final int position;
  final Map errorMessages;
  final Map validations;
  final Map decorations;
  final Map keyboardTypes;

  @override
  _SimpleListCheckbox createState() => new _SimpleListCheckbox();
}

class _SimpleListCheckbox extends State<SimpleListCheckbox> {
  dynamic item;
  List<dynamic> selectItems = [];

  String isRequired(item, value) {
    if (value.isEmpty) {
      return widget.errorMessages[item['key']] ?? 'Please enter some text';
    }
    return null;
  }

  @override
  void initState() {
    super.initState();
    item = widget.item;
    for (var i = 0; i < item['items'].length; i++) {
      if (item['items'][i]['value'] == true) {
        selectItems.add(i);
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    List<Widget> checkboxes = [];
    if (Fun.labelHidden(item)) {
      checkboxes.add(Container(
        padding: EdgeInsets.only(bottom: 5),
        child: RichText(
          text: TextSpan(
            text: item['label'],
            style: new TextStyle(
                letterSpacing: 1,
                fontWeight: FontWeight.bold,
                fontSize: FontSize.FONT_16,
                color: AppColors.APP_COLOR_BLACK,
                fontFamily: FontFamily.Gilroy),
            children: <TextSpan>[
              //  item['label'].toString().endsWith('*')
              item['required'] == true
                  ? TextSpan(
                      text: ' *',
                      style: TextStyle(
                          letterSpacing: 1,
                          fontWeight: FontWeight.bold,
                          color: AppColors.errorWarning))
                  : TextSpan(
                      text: '',
                      style: TextStyle(
                          letterSpacing: 1,
                          fontWeight: FontWeight.bold,
                          fontSize: FontSize.FONT_13,
                          fontFamily: FontFamily.Gilroy,
                          color: AppColors.errorWarning)),
            ],
          ),
        ),
      ));
    }
    for (var i = 0; i < item['items'].length; i++) {
      checkboxes.add(
        new Row(
          children: <Widget>[
            new Expanded(child: new Text(item['items'][i]['label'])),
            new Checkbox(
              activeColor: widget.secondaryColor,
              checkColor: Colors.white,
              tristate: true,
              value: item['items'][i]['value'],
              onChanged: (bool value) {
                this.setState(
                  () {
                    item['items'][i]['value'] = value;

                    if (value == null) {
                      value = false;
                    }
                    if (value) {
                      selectItems.add(i);
                    } else {
                      selectItems.remove(i);
                    }
                    widget.onChange(widget.position, selectItems);
                    //_handleChanged();
                  },
                );
              },
            ),
          ],
        ),
      );
    }
    return new Container(
      margin: new EdgeInsets.only(top: 5.0),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: checkboxes,
      ),
    );
  }
}

==> 0.0.70.tar.gz: lib/JsonFormComponent/components/simple_checkbox.dart <==
import 'package:bui_component/Constants/AppColors.dart';
import 'package:bui_component/Constants/fontFamily.dart';
import 'package:bui_component/Constants/fontSize.dart';
import 'package:flutter/material.dart';

import '../functions.dart';

class SimpleListCheckbox extends StatefulWidget {
  SimpleListCheckbox({
    Key key,
    this.item,
    this.onChange,
    this.position,
    this.errorMessages = const {},
    this.validations = const {},
    this.decorations = const {},
    this.keyboardTypes = const {},
    this.primaryColor,
    this.secondaryColor,
  }) : super(key: key);
  final Color primaryColor;
  final Color secondaryColor;
  final dynamic item;
  final Function onChange;
  final int position;
  final Map errorMessages;
  final Map validations;
  final Map decorations;
  final Map keyboardTypes;

  @override
  _SimpleListCheckbox createState() => new _SimpleListCheckbox();
}

class _SimpleListCheckbox extends State<SimpleListCheckbox> {
  dynamic item;
  List<dynamic> selectItems = [];

  String isRequired(item, value) {
    if (value.isEmpty) {
      return widget.errorMessages[item['key']] ?? 'Please enter some text';
    }
    return null;
  }

  @override
  void initState() {
    super.initState();
    item = widget.item;
    for (var i = 0; i < item['items'].length; i++) {
      if (item['items'][i]['value'] == true) {
        selectItems.add(i);
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    List<Widget> checkboxes = [];
    if (Fun.labelHidden(item)) {
      checkboxes.add(Visibility(
        visible: item['visibility'] != null ? item['visibility'] : true,
        child: Container(
          padding: EdgeInsets.only(bottom: 5),
          child: RichText(
            text: TextSpan(
              text: item['label'],
              style: new TextStyle(
                  letterSpacing: 1,
                  fontWeight: FontWeight.bold,
                  fontSize: FontSize.FONT_16,
                  color: AppColors.APP_COLOR_BLACK,
                  fontFamily: FontFamily.Gilroy),
              children: <TextSpan>[
                //  item['label'].toString().endsWith('*')
                item['required'] == true
                    ? TextSpan(
                        text: ' *',
                        style: TextStyle(
                            letterSpacing: 1,
                            fontWeight: FontWeight.bold,
                            color: AppColors.errorWarning))
                    : TextSpan(
                        text: '',
                        style: TextStyle(
                            letterSpacing: 1,
                            fontWeight: FontWeight.bold,
                            fontSize: FontSize.FONT_13,
                            fontFamily: FontFamily.Gilroy,
                            color: AppColors.errorWarning)),
              ],
            ),
          ),
        ),
      ));
    }
    for (var i = 0; i < item['items'].length; i++) {
      checkboxes.add(
        new Row(
          children: <Widget>[
            new Expanded(child: new Text(item['items'][i]['label'])),
            new Checkbox(
              activeColor: widget.secondaryColor,
              checkColor: Colors.white,
              tristate: true,
              value: item['items'][i]['value'],
              onChanged: (bool value) {
                this.setState(
                  () {
                    item['items'][i]['value'] = value;

                    if (value == null) {
                      value = false;
                    }
                    if (value) {
                      selectItems.add(i);
                    } else {
                      selectItems.remove(i);
                    }
                    widget.onChange(widget.position, selectItems);
                    //_handleChanged();
                  },
                );
              },
            ),
          ],
        ),
      );
    }
    return Visibility(
      visible: item['visibility'] != null ? item['visibility'] : true,
      child: new Container(
        margin: new EdgeInsets.only(top: 5.0),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: checkboxes,
        ),
      ),
    );
  }
}
